@@ -834,6 +834,7 @@ bool ConsolePlayer::open (void)
     m_driver.selected = &m_driver.null;
     m_speed.current   = m_speed.max;
 #ifdef FEAT_NEW_PLAY_API
+    m_mixer.clear();
     m_mixer.setFastForward(m_speed.current);
 #else
     m_engine.fastForward(100 * m_speed.current);
@@ -890,7 +891,9 @@ bool ConsolePlayer::open (void)
 
 void ConsolePlayer::close ()
 {
+#ifndef FEAT_NEW_PLAY_API
     m_engine.stop();
+#endif
     if (m_state == playerExit)
     {   // Natural finish
         emuflush ();
@@ -966,6 +969,8 @@ bool ConsolePlayer::play()
                 m_state = playerError;
                 return false;
             }
+            if (!buffer) UNLIKELY
+                break;
             if (samples > 0)
                 m_mixer.doMix(buffers, samples);
             else break;
@@ -1013,7 +1018,9 @@ bool ConsolePlayer::play()
     default:
         if (m_quietLevel < 2)
             cerr << endl;
+#ifndef FEAT_NEW_PLAY_API
         m_engine.stop ();
+#endif
 #if HAVE_TSID == 1
         if (m_tsid)
         {
@@ -1044,7 +1051,9 @@ bool ConsolePlayer::play()
 void ConsolePlayer::stop ()
 {
     m_state = playerStopped;
+#ifndef FEAT_NEW_PLAY_API
     m_engine.stop ();
+#endif
 }
 
 
